<?php


/**
 **********************************************************
 * Name:     MediawikiPlayer
 * Desc:     Embedds a mediaplayer into a wiki page
 *
 * Version:  0.2.4
 *
 * Author:   Andrew Fitzgerald (contact@swiftlytilting.com)
 * Homepage: http://www.mediawiki.org/wiki/Extension:MediawikiPlayer
 *           http://www.swiftlytilting.com/
 *
 * License:  GNU GPL
 *
 ***********************************************************
 */

// using $wgScriptPath so head em off at the pass
if ( !defined( 'MEDIAWIKI' ) ) {
    echo "Not a valid entry point";
    exit( 1 );
}
 
$wgExtensionCredits['parserhook'][] = array(
       'name' => 'MediawikiPlayer',
       'author' =>'[http://swiftlytilting.com Andrew Fitzgerald]', 
       'url' => 'http://www.mediawiki.org/wiki/Extension:MediawikiPlayer', 
       'description' => 'Embeds a media player into a wiki page',
       'descriptionmsg' => "mediawikiplayer-desc", // Same as above but name of a message, for i18n - string, added in 1.12.0
		 'version' => '0.2.4',
		 'path' => __FILE__,
       );


//Avoid unstubbing $wgParser on setHook() too early on modern (1.12+) MW versions, as per r35980
if ( defined( 'MW_SUPPORTS_PARSERFIRSTCALLINIT' ) ) {
	$wgHooks['ParserFirstCallInit'][] = 'efMWPlayerSetup';
} else { // Otherwise do things the old fashioned way
	$wgExtensionFunctions[] = 'efMWPlayerSetup';
}
/**
 * Set up the extension variables and functions
 */
function efMWPlayerSetup() 
{
	global $wgParser, $wgMWPlayerID, $wgMWPlayerConfig, $wgMWPlayerDefaultSettings,$wgScriptPath , $wgMWPlayerDir;
	$wgMWPlayerID = 0;
	$wgMWPlayerDir = $wgScriptPath  . '/extensions/MediawikiPlayer';;
	$wgMWPlayerConfig = array();
	
	$wgMWPlayerDefaultSettings = array(
      'width' => '400',
      'height' => '300',
      'allowfullscreen' => 'true',
      'backcolor' => 'eeeeee',
   );
               
	$wgParser->setHook( 'mediaplayer', 'efMWPlayerRender' );
	$wgParser->setHook( 'mp3player', 'efMWPlayerRenderMP3' );
       return true;   
}
 
/**
 * Handler for mp3player tag
 */
function efMWPlayerRenderMP3( $input, $args, $parser ) 
{
	$args['height'] = '20';
	return efMWPlayerRender( $input, $args, $parser);
}

/**
 * Handler for mediaplayer tag
 */
function efMWPlayerRender( $input, $args, $parser ) 
{
	global $wgMWPlayerID, $wgScriptPath , $wgMWPlayerDir, $wgMWPlayerDefaultSettings, $wgMWPlayerConfig;
	
	if (!is_int($wgMWPlayerID))
	{
		$wgMWPlayerID = 0;
	}
	
	$wgMWPlayerID++;   
	
		
	if (strtolower(substr($input,0,5)) == 'file:')
	{	
		$image = wfFindFile(substr($input,5));		
		if ($image)
		{
			$input = $image->getFullURL();								
		}
		else
		{
			return 'Error loading file:' . Xml::encodeJsVar(substr($input,5));
		}
	}

	$paramArr = array('allowfullscreen', 'allowscriptaccess', 'wmode', 'flashvars');
	
	if (isset($wgMWPlayerConfig) 
				&& array_key_exists('MWPlayerConfig', $args) 
				&& array_key_exists($args['MWPlayerConfig'], $wgMWPlayerConfig))
	{ 
		$wgMWPlayerDefaultSettings = $wgMWPlayerConfig[$args['MWPlayerConfig']];
		unset($args['MWPlayerConfig']);
	
	} 
	
		
	foreach ($wgMWPlayerDefaultSettings as $n => $v)
	{	
		if (!array_key_exists($n, $args))
		{	$args[$n] = $v;
		}
	}
	 
	if ((!array_key_exists('file',$args)) && (trim($input) != ''))
	{		$args['file'] = $input;
	}
	
	
	$wgMWPlayerIDHTML = htmlspecialchars($wgMWPlayerID);
	
	$code = "<span id=\"MWPlayer-$wgMWPlayerIDHTML\">The player will show in this paragraph</span>\n";
		
	if ($wgMWPlayerID ==1 )
	{	
		$scriptUrl = htmlspecialchars($wgMWPlayerDir . '/swfobject.js');
		$code .= "<script type='text/javascript' src=\"$scriptUrl\"></script>\n";
	}
	
	$code .= "<script type='text/javascript'>\n";
	$code .= "// <![CDATA[\n";	
	
	$playerUrl = Xml::encodeJsVar($wgMWPlayerDir. '/player.swf');
	$width = Xml::encodeJsVar($args['width']);
	$height = Xml::encodeJsVar($args['height']);
	
	$code .= "var s1 = new SWFObject($playerUrl,'player',$width,$height,'9');\n";	 

	foreach( $args as $name => $value )
	{	
		$value = str_replace(array( ':PLAYERDIR:'), array( Xml::escapeJsString($wgMWPlayerDir) ), $value);
		
		$newname = Xml::encodeJsVar($name); 
		$newvalue = Xml::encodeJsVar($value);
         
		if (in_array($name,$paramArr))
		{	
			$code .= "s1.addParam($newname,$newvalue);\n";
		} else
		{
			$code .= "s1.addVariable($newname,$newvalue);\n";
		}
	}
	
   $wgMWPlayerIDJS = Xml::encodeJsVar($wgMWPlayerID);
	
	$code .= "s1.write('MWPlayer-$wgMWPlayerIDJS');\n";
	$code .= "// ]]>\n";
	$code .= "</script>";
	return $code;
}